@@ -476,3 +476,15 @@ predictors.foba <- function(x, k = NULL, ...)
     names(predict(x, k = k, type = "coefficients")$selected.variables)
   }
 
+predictors.dsa <- function(x, cuts = NULL, ...)
+  {
+    if(is.null(cuts) & !is.null(x$tuneValue))
+      {
+        cuts <- x$tuneValue$.cut.off.growth[1]
+      } else {
+        if(is.null(cuts)) stop("please supply a value for 'cuts'")
+      }
+    tmp <- x$var.importance[,cuts]
+    names(tmp)[which(tmp != 0)]
+
+  }
